@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -26,8 +26,8 @@ CategoryTypeComboBox::CategoryTypeComboBox(bool customType, QWidget *parent)
     : QComboBox(parent)
 {
     addItem(i18n("All"), QVariant::fromValue(LoggingCategory::All));
-    addItem(i18n("Info"), QVariant::fromValue(LoggingCategory::Info));
     addItem(i18n("Debug"), QVariant::fromValue(LoggingCategory::Debug));
+    addItem(i18n("Info"), QVariant::fromValue(LoggingCategory::Info));
     addItem(i18n("Warning"), QVariant::fromValue(LoggingCategory::Warning));
     addItem(i18n("Critical"), QVariant::fromValue(LoggingCategory::Critical));
     if (!customType) {
@@ -37,7 +37,11 @@ CategoryTypeComboBox::CategoryTypeComboBox(bool customType, QWidget *parent)
 
 CategoryTypeComboBox::~CategoryTypeComboBox()
 {
+}
 
+void CategoryTypeComboBox::restoreToDefault()
+{
+    setType(mDefaultCategories);
 }
 
 void CategoryTypeComboBox::setType(LoggingCategory::LoggingType type)
@@ -55,3 +59,18 @@ LoggingCategory::LoggingType CategoryTypeComboBox::type() const
 {
     return currentData().value<LoggingCategory::LoggingType>();
 }
+
+bool CategoryTypeComboBox::loggingCategoryIsNotDefault() const
+{
+    return type() != mDefaultCategories;
+}
+
+void CategoryTypeComboBox::setDefaultCategories(const LoggingCategory::LoggingType &defaultCategories)
+{
+    mDefaultCategories = defaultCategories;
+}
+
+LoggingCategory::LoggingType CategoryTypeComboBox::defaultCategories() const
+{
+    return mDefaultCategories;
+}
