@@ -33,7 +33,7 @@ public:
     explicit KDEApplicationDebugSettingPage(QWidget *parent = nullptr);
     ~KDEApplicationDebugSettingPage() override;
     void fillList(const LoggingCategory::List &list);
-    LoggingCategory::List rules(bool forceSavingAllRules) const;
+    Q_REQUIRED_RESULT LoggingCategory::List rules(bool forceSavingAllRules) const;
     void insertCategories(const LoggingCategory::List &list);
 
     void restoreToDefault();
@@ -42,13 +42,15 @@ protected:
     bool eventFilter(QObject *obj, QEvent *event) override;
 
 private:
-    void slotSelectAll();
-    void slotDeselectAll();
+    void slotSelectAllDebug();
+    void slotDeselectAllDebug();
+    void slotDeselectAllMessages();
 
     KDEApplicationTreeListWidget *mTreeListWidget = nullptr;
     KTreeWidgetSearchLine *mTreeListWidgetSearchLine = nullptr;
     QPushButton *mEnableDebug = nullptr;
     QPushButton *mTurnOffDebug = nullptr;
+    QPushButton *mTurnOffAllMessages = nullptr;
 };
 
 #endif // KDEAPPLICATIONDEBUGSETTINGPAGE_H
